pub fn route_action_outputs(
action: &PlanAction,
produced_confidential: HashMap<String, Zeroizing<Vec<u8>>>,
produced_public: HashMap<String, Vec<u8>>,
run_scope: &mut ConfidentialRunScope,
) -> Result<(), NxdError>Expand description
Route the exact declared confidential and public outputs into the bounded action run scope. Public identity artifacts are kept separate on the wire so a provider cannot disguise private bytes as public output.