LifecycleIntent

Enum LifecycleIntent 

pub enum LifecycleIntent {
    Observe,
    BuildOnly,
    Switch,
    Boot,
    Test,
    Install,
    Destroy,
    Convert,
    Recovery,
    Exec,
}
Operator-selected host lifecycle intent.

Intent is not read from host flake desired state. Identical selectors with different intents must produce different plan digests.

Variants



Observe

Side-effect-free observe; plan contains preconditions and noop/empty actions only.



BuildOnly

Build system derivation/path only; must not require SSH or provider mutation.



Switch

Activate current generation.



Boot

Set default boot generation.



Test

Temporary activation.



Install

Install / first-boot / recreate path.



Destroy

Explicit guest/provider destroy.



Convert

In-place convert.



Recovery

Provider-owned recovery through the normal reviewed plan/apply DAG.



Exec

Execute an explicitly reviewed argv vector through the target provider.

Implementations

Source

impl LifecycleIntent

pub fn as_str(self) -> &'static str

pub fn parse(value: &str) -> Result<Self, String>

pub fn requires_destructive_approval(self) -> bool

Intents that may require destructive approval evidence at apply time.

pub fn forbids_target_mutation(self) -> bool

True when planning/applying must not contact the target host or mutate providers.