pub struct PlanEnvelope {
pub api_version: String,
pub kind: PlanKind,
pub metadata: PlanMetadata,
pub spec: PlanSpec,
}Fields
api_version: Stringkind: PlanKindmetadata: PlanMetadataspec: PlanSpecImplementations
Sourceimpl PlanEnvelope
impl PlanEnvelope
Sourcepub fn new(
name: impl Into<String>,
input_digests: PlanInputDigests,
selectors: Vec<String>,
expires_at_unix: u64,
preconditions: Vec<PlanPrecondition>,
actions: Vec<PlanAction>,
) -> Self
pub fn new( name: impl Into<String>, input_digests: PlanInputDigests, selectors: Vec<String>, expires_at_unix: u64, preconditions: Vec<PlanPrecondition>, actions: Vec<PlanAction>, ) -> Self
Build a plan and synthesize approval requirements from high-risk actions.
Destructive and identity-critical actions require digest-bound confirmation
or --approval-evidence at apply (see host_lifecycle::approval_requirements_from_actions).
pub fn new_with_lifecycle( name: impl Into<String>, input_digests: PlanInputDigests, selectors: Vec<String>, expires_at_unix: u64, preconditions: Vec<PlanPrecondition>, actions: Vec<PlanAction>, lifecycle_intent: Option<LifecycleIntent>, approval_requirements: Vec<ApprovalRequirement>, ) -> Self
Sourcepub fn with_provider_runtimes(
self,
runtimes: Vec<ProviderRuntimeRecord>,
) -> Self
pub fn with_provider_runtimes( self, runtimes: Vec<ProviderRuntimeRecord>, ) -> Self
Attach composed provider executable identities to a plan (protocol path).
pub fn with_secret_runtimes(self, runtimes: Vec<SecretRuntimeRecord>) -> Self
pub fn digest(&self) -> Result<String, Error>